Same change as done for panel-samsung-atna33xc20. Extend the autosuspend
delay to avoid oscillating between power status during boot.

Signed-off-by: Drew Davenport <ddavenp...@chromium.org>
---

 drivers/gpu/drm/bridge/parade-ps8640.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/bridge/parade-ps8640.c 
b/drivers/gpu/drm/bridge/parade-ps8640.c
index 6a614e54b383c..f74090a9cc9e8 100644
--- a/drivers/gpu/drm/bridge/parade-ps8640.c
+++ b/drivers/gpu/drm/bridge/parade-ps8640.c
@@ -734,13 +734,13 @@ static int ps8640_probe(struct i2c_client *client)
        pm_runtime_enable(dev);
        /*
         * Powering on ps8640 takes ~300ms. To avoid wasting time on power
         * cycling ps8640 too often, set autosuspend_delay to 1000ms to ensure
         * the bridge wouldn't suspend in between each _aux_transfer_msg() call
         * during EDID read (~20ms in my experiment) and in between the last
         * _aux_transfer_msg() call during EDID read and the _pre_enable() call
         * (~100ms in my experiment).
         */
-       pm_runtime_set_autosuspend_delay(dev, 1000);
+       pm_runtime_set_autosuspend_delay(dev, 2000);
        pm_runtime_use_autosuspend(dev);
        pm_suspend_ignore_children(dev, true);
        ret = devm_add_action_or_reset(dev, ps8640_runtime_disable, dev);
@@ -734,13 +734,13 @@ static int ps8640_probe(struct i2c_client *client)
        /*
         * Powering on ps8640 takes ~300ms. To avoid wasting time on power
-        * cycling ps8640 too often, set autosuspend_delay to 1000ms to ensure
+        * cycling ps8640 too often, set autosuspend_delay to 2000ms to ensure
         * the bridge wouldn't suspend in between each _aux_transfer_msg() call
         * during EDID read (~20ms in my experiment) and in between the last
-- 
2.38.1.584.g0f3c55d4c2-goog

Reply via email to